@@ -4,7 +4,7 @@
 from __future__ import print_function, absolute_import, unicode_literals
 
 __all__ = ["corner", "hist2d", "error_ellipse"]
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 __author__ = "Dan Foreman-Mackey (danfm@nyu.edu)"
 __copyright__ = "Copyright 2013 Daniel Foreman-Mackey"
 __contributors__ = [    # Alphabetical by first name.
@@ -23,7 +23,35 @@ import matplotlib.cm as cm
 
 
 def corner(xs, labels=None, extents=None, truths=None, truth_color="#4682b4",
-           **kwargs):
+           scale_hist=False, quantiles=[], **kwargs):
+    """
+    Make a *sick* corner plot showing the projections of a set of samples
+    drawn in a multi-dimensional space.
+
+    :param xs: ``(nsamples, ndim)``
+        The samples. This should be a 1- or 2-dimensional array. For a 1-D
+        array this results in a simple histogram. For a 2-D array, the zeroth
+        axis is the list of samples and the next axis are the dimensions of
+        the space.
+
+    :param labels: ``ndim`` (optional)
+        A list of names for the dimensions.
+
+    :param truths: ``ndim`` (optional)
+        A list of reference values to indicate on the plots.
+
+    :param truth_color: (optional)
+        A ``matplotlib`` style color for the ``truths`` makers.
+
+    :param quantiles: (optional)
+        A list of fractional quantiles to show on the 1-D histograms as
+        vertical dashed lines.
+
+    :param scale_hist: (optional)
+        Should the 1-D histograms be scaled in such a way that the zero line
+        is visible?
+
+    """
 
     # Deal with 1D sample lists.
     xs = np.atleast_1d(xs)
@@ -54,13 +82,25 @@ def corner(xs, labels=None, extents=None, truths=None, truth_color="#4682b4",
     for i, x in enumerate(xs):
         # Plot the histograms.
         ax = fig.add_subplot(K, K, i * (K + 1) + 1)
-        ax.hist(x, bins=kwargs.get("bins", 50), range=extents[i],
+        n, b, p = ax.hist(x, bins=kwargs.get("bins", 50), range=extents[i],
                 histtype="step", color=kwargs.get("color", "k"))
         if truths is not None:
             ax.axvline(truths[i], color=truth_color)
 
+        # Plot quantiles if wanted.
+        if len(quantiles) > 0:
+            xsorted = sorted(x)
+            for q in quantiles:
+                ax.axvline(xsorted[int(q * len(xsorted))], ls="dashed",
+                           color=kwargs.get("color", "k"))
+
         # Set up the axes.
         ax.set_xlim(extents[i])
+        if scale_hist:
+            maxn = np.max(n)
+            ax.set_ylim(-0.1 * maxn, 1.1 * maxn)
+        else:
+            ax.set_ylim(0, 1.1 * np.max(n))
         ax.set_yticklabels([])
         ax.xaxis.set_major_locator(MaxNLocator(5))
 
@@ -177,7 +217,8 @@ def hist2d(x, y, *args, **kwargs):
     data = np.vstack([x, y])
     mu = np.mean(data, axis=1)
     cov = np.cov(data)
-    error_ellipse(mu, cov, ax=ax, edgecolor="r", ls="dashed")
+    if kwargs.pop("plot_ellipse", False):
+        error_ellipse(mu, cov, ax=ax, edgecolor="r", ls="dashed")
 
     ax.set_xlim(extent[0])
     ax.set_ylim(extent[1])
